#!/bin/bash

#       build-docutils.sh
#
#       Copyright 2011 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

### Pkg variables
name=docutils
version=0.7
arch=noarch
build=72.1
ext=txz

working_dir=$PWD

#create a temporary directory
tmpdir="/tmp/docutils.$RANDOM$$$RANDOM"
trap 'rm -r "$tmpdir"' EXIT
mkdir -m 700 "$tmpdir" || exit 1

#build and install
python setup.py install --prefix="$tmpdir"/usr || exit 1

#strip the .py's
cd "$tmpdir/usr/bin" || exit 1
for i in ./*.py ; do
  mv "$i" "${i%.py}"
done

cd "$tmpdir" || exit 1

#the slack-desc
#install/ should not already be there
mkdir install/ || exit 1

#    |-----handy-ruler------------------------------------------------------|
cat > install/slack-desc <<EOF
$name: Docutils - Python Documentation Utilities
$name:
$name: Docutils is a system for processing plaintext documentation into
$name: useful formats, such as HTML, XML, and LaTeX.  It supports multiple
$name: types of input, such as standalone files (implemented), inline
$name: documentation from Python modules and packages (under development),
$name: PEPs (Python Enhancement Proposals) (implemented), and others as
$name: discovered.
$name:
$name:
$name:
EOF

#the build script
mkdir -p usr/src/"$name-$version"
cp "$working_dir/build-$name.sh" "$_" || exit 1

#basic doc
mkdir -p usr/doc/"$name-$version"
for doc in BUGS.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt; do
  cp "$working_dir/$doc" usr/doc/"$name-$version"
done

#making package
makepkg -l y -c y "$working_dir/$name-$version-$arch-$build.$ext"
